summaryrefslogtreecommitdiffstats
path: root/include/getopt.h
diff options
context:
space:
mode:
authorache <ache@FreeBSD.org>2004-02-24 08:09:20 +0000
committerache <ache@FreeBSD.org>2004-02-24 08:09:20 +0000
commita0ff4ed2fe3a44756f7a5db8cecb04c1057c19aa (patch)
tree1e9077c2d522a4d103348c536589bbc414b4071b /include/getopt.h
parentaf4255ff22419104dee7dd3e695cc0e642b94399 (diff)
downloadFreeBSD-src-a0ff4ed2fe3a44756f7a5db8cecb04c1057c19aa.zip
FreeBSD-src-a0ff4ed2fe3a44756f7a5db8cecb04c1057c19aa.tar.gz
Add getopt_long_only()
Diffstat (limited to 'include/getopt.h')
-rw-r--r--include/getopt.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/include/getopt.h b/include/getopt.h
index 4943d04..dca3c3d 100644
--- a/include/getopt.h
+++ b/include/getopt.h
@@ -43,7 +43,7 @@
#include <sys/cdefs.h>
/*
* GNU-like getopt_long() with 4.4BSD optreset extension.
* getopt() is declared here too for GNU programs.
*/
#define no_argument 0
@@ -67,6 +67,8 @@ struct option {
__BEGIN_DECLS
int getopt_long(int, char * const *, const char *,
const struct option *, int *);
+int getopt_long_only(int, char * const *, const char *,
+ const struct option *, int *);
#ifndef _GETOPT_DECLARED
#define _GETOPT_DECLARED
int getopt(int, char * const [], const char *);
@@ -43,7 +43,7 @@
#include <sys/cdefs.h>
/*
- * GNU-like getopt_long() with 4.4BSD optreset extension.
+ * GNU-like getopt_long()/getopt_long_only() with 4.4BSD optreset extension.
* getopt() is declared here too for GNU programs.
*/
OpenPOWER on IntegriCloud